@@ -3,7 +3,7 @@
 
 -- |
 -- Module      :  Test.ChasingBottoms.SemanticOrd
--- Copyright   :  (c) Nils Anders Danielsson 2004-2014
+-- Copyright   :  (c) Nils Anders Danielsson 2004-2015
 -- License     :  See the file LICENCE.
 --
 -- Maintainer  :  http://www.cse.chalmers.se/~nad/
@@ -137,8 +137,8 @@ liftAppr tweak op x y = op tweak (appr x) (appr y)
 
 ------------------------------------------------------------------------
 
-type Rel' = (Data a, Data b) => Tweak -> a -> b -> Bool
-type Rel  = (Data a, Data b) => a -> b -> Bool
+type Rel' = forall a b. (Data a, Data b) => Tweak -> a -> b -> Bool
+type Rel  = forall a b. (Data a, Data b) => a -> b -> Bool
 
 semanticEq', semanticLE' :: Rel'
 
